#[non_exhaustive]pub struct APB_SARADC<'a> { /* private fields */ }unstable only.Expand description
APB_SARADC peripheral singleton
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Implementations
Sourceimpl APB_SARADC<'_>
impl APB_SARADC<'_>
Sourcepub unsafe fn steal() -> Self
pub unsafe fn steal() -> Self
Unsafely creates an instance of this peripheral out of thin air.
Safety
The caller must ensure that only one instance of this type is used at a time.
Sourcepub unsafe fn clone_unchecked(&self) -> Self
pub unsafe fn clone_unchecked(&self) -> Self
Unsafely clone this peripheral reference.
Safety
The caller must ensure that only one instance of this type is used at a time.
Sourcepub fn reborrow(&mut self) -> APB_SARADC<'_>
pub fn reborrow(&mut self) -> APB_SARADC<'_>
Creates a new peripheral reference with a shorter lifetime.
Use this method to keep working with the peripheral after the driver that consumes it is dropped.
Sourceimpl APB_SARADC<'_>
impl APB_SARADC<'_>
Sourcepub const PTR: *const <ADC as Deref>::Target = pac::ADC::PTR
pub const PTR: *const <ADC as Deref>::Target = pac::ADC::PTR
Pointer to the register block
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Sourcepub const fn ptr() -> *const <ADC as Deref>::Target
pub const fn ptr() -> *const <ADC as Deref>::Target
Return the pointer to the register block
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Sourcepub fn regs<'a>() -> &'a <ADC as Deref>::Target
pub fn regs<'a>() -> &'a <ADC as Deref>::Target
Return a reference to the register block
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Sourcepub fn register_block(&self) -> &<ADC as Deref>::Target
pub fn register_block(&self) -> &<ADC as Deref>::Target
Return a reference to the register block
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.