#[non_exhaustive]pub struct MIPI_DSI_BRIDGE<'a> { /* private fields */ }unstable only.Expand description
MIPI_DSI_BRIDGE peripheral singleton
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Implementations
Sourceimpl MIPI_DSI_BRIDGE<'_>
impl MIPI_DSI_BRIDGE<'_>
Sourcepub unsafe fn steal() -> Self
pub unsafe fn steal() -> Self
Unsafely creates an instance of this peripheral out of thin air.
Safety
The caller must ensure that only one instance of this type is used at a time.
Sourcepub unsafe fn clone_unchecked(&self) -> Self
pub unsafe fn clone_unchecked(&self) -> Self
Unsafely clone this peripheral reference.
Safety
The caller must ensure that only one instance of this type is used at a time.
Sourcepub fn reborrow(&mut self) -> MIPI_DSI_BRIDGE<'_>
pub fn reborrow(&mut self) -> MIPI_DSI_BRIDGE<'_>
Creates a new peripheral reference with a shorter lifetime.
Use this method to keep working with the peripheral after the driver that consumes it is dropped.
Sourceimpl MIPI_DSI_BRIDGE<'_>
impl MIPI_DSI_BRIDGE<'_>
Sourcepub const PTR: *const <MIPI_DSI_BRIDGE as Deref>::Target = pac::MIPI_DSI_BRIDGE::PTR
pub const PTR: *const <MIPI_DSI_BRIDGE as Deref>::Target = pac::MIPI_DSI_BRIDGE::PTR
Pointer to the register block
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Sourcepub const fn ptr() -> *const <MIPI_DSI_BRIDGE as Deref>::Target
pub const fn ptr() -> *const <MIPI_DSI_BRIDGE as Deref>::Target
Return the pointer to the register block
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Sourcepub fn regs<'a>() -> &'a <MIPI_DSI_BRIDGE as Deref>::Target
pub fn regs<'a>() -> &'a <MIPI_DSI_BRIDGE as Deref>::Target
Return a reference to the register block
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Sourcepub fn register_block(&self) -> &<MIPI_DSI_BRIDGE as Deref>::Target
pub fn register_block(&self) -> &<MIPI_DSI_BRIDGE as Deref>::Target
Return a reference to the register block
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.